@@ -2,14 +2,14 @@
 #' @title Add a single new known location record to a table
 #' 
 #' @description Incoming \code{longitude} and \code{latitude} values are compared 
-#' against the incoming \code{locationTbl} to see if the are already within
-#' \code{radius} meters of an existing entry.  A new record is created for
+#' against the incoming \code{locationTbl} to see if they are already within
+#' \code{distanceThreshold} meters of an existing entry.  A new record is created for
 #' if the location is not already found in \code{locationTbl}.
 #' 
-#' @param locationTbl Tibble of known locations, Default: NULL
-#' @param longitude Single longitude in decimal degrees E, Default: NULL
-#' @param latitude Single latitude in decimal degrees N, Default: NULL
-#' @param radius Radius in meters, Default: NULL
+#' @param locationTbl Tibble of known locations.
+#' @param longitude Single longitude in decimal degrees E.
+#' @param latitude Single latitude in decimal degrees N.
+#' @param distanceThreshold Distance in meters.
 #' @param stateDataset Name of spatial dataset to use for determining state
 #' codes, Default: 'NaturalEarthAdm1'
 #' @param elevationService Name of the elevation service to use for determining
@@ -36,7 +36,7 @@
 #' 
 #' locationTbl <- 
 #'   locationTbl %>%
-#'   table_addSingleLocation(lon, lat, radius = 500)
+#'   table_addSingleLocation(lon, lat, distanceThreshold = 500)
 #' }
 #' 
 #' @seealso \link{table_addLocation}
@@ -51,7 +51,7 @@ table_addSingleLocation <- function(
   locationTbl = NULL,
   longitude = NULL,
   latitude = NULL,
-  radius = NULL,
+  distanceThreshold = NULL,
   stateDataset = "NaturalEarthAdm1",
   elevationService = NULL,
   addressService = NULL,
@@ -62,10 +62,8 @@ table_addSingleLocation <- function(
   
   # ----- Validate parameters --------------------------------------------------
   
-  MazamaCoreUtils::stopIfNull(locationTbl)
-  MazamaCoreUtils::stopIfNull(longitude)
-  MazamaCoreUtils::stopIfNull(latitude)
-  MazamaCoreUtils::stopIfNull(radius)
+  MazamaLocationUtils::validateLocationTbl(locationTbl, locationOnly = FALSE)
+  MazamaCoreUtils::stopIfNull(distanceThreshold)
   MazamaCoreUtils::stopIfNull(stateDataset)
   
   if ( length(longitude) > 1 || length(latitude) > 1 ) {
@@ -74,6 +72,8 @@ table_addSingleLocation <- function(
       "  table_addLocation(...)\n"
     ))
   }
+
+  MazamaLocationUtils::validateLonLat(longitude, latitude)
   
   if ( !exists(stateDataset) ) {
     stop(paste0(
@@ -84,12 +84,12 @@ table_addSingleLocation <- function(
   
   # ----- Check for existing location ------------------------------------------
   
-  locationID <- table_getLocationID(locationTbl, longitude, latitude, radius)
+  locationID <- table_getLocationID(locationTbl, longitude, latitude, distanceThreshold)
   
   if ( !is.na(locationID) ) {
     stop(sprintf(
       "The known location %s already exists < %d meters from the requested location.",
-      locationID, radius
+      locationID, distanceThreshold
     ))
   }
   
