@@ -11,8 +11,8 @@ test_that("table_getNearestLocation() works", {
   lon <- -120.325278
   lat <- 47.423333
   
-  testClose <- table_getNearestLocation(locationTbl, lon, lat, radius = 50)
-  testFar <- table_getNearestLocation(locationTbl, lon, lat, radius = 5000)
+  testClose <- table_getNearestLocation(locationTbl, lon, lat, distanceThreshold = 100)
+  testFar <- table_getNearestLocation(locationTbl, lon, lat, distanceThreshold = 10000)
   expect_equal(testClose, emptyRecord)
   expect_equal(testFar, wenatcheeRecord)
 })
